multidim.PointCloud.cover_ball — GDA Toolbox v1.0 Manual

# multidim.PointCloud.cover_ball

`PointCloud.` `cover_ball`(point_index=None)

  Find a ball that covers the entire PointCloud.

  Parameters: | point_index : int If point_index is given, we use that point as the center. If point_index is None (default), then we compute the point neareast the center-of-mass, which requires an extra `numpy.mean()` and `scipy.spatial.distance.cdist()` call.
  Returns: | ball : dict with keys ‘index’ (index of designated center point), ‘point’ (coordinates of designated center point), and ‘radius’ (radius of ball)

#### Previous topic

multidim.PointCloud.check

#### Next topic

multidim.PointCloud.dists